@@ -12,7 +12,7 @@ use Hash::Util qw(lock_hashref);
 use Module::Load;
 use Types::Standard qw(InstanceOf HashRef);
 
-our $VERSION = '0.70';
+our $VERSION = '0.71';
 
 # Global var for saving last success validation valid input.
 my $valid_input;
@@ -75,6 +75,10 @@ sub BUILD {
 sub validate {
     my ($self, %params) = @_;
 
+    # We need to unset value of this global var.
+    $valid_input = undef;
+
+    # Now works with arguments.
     my $profile = %params{profile};
     my $input   = %params{input} // $self->dsl->body_parameters->as_hashref_mixed;
     my $lang    = %params{lang};
@@ -83,9 +87,6 @@ sub validate {
         $self->_validator_language($lang);
     }
 
-    # We need to unset value of this global var.
-    $valid_input = undef;
-
     my $result = $self->_validate($input, $profile);
 
     if ($result->success) {
@@ -97,7 +98,10 @@ sub validate {
 }
 
 sub validated {
-    return $valid_input;
+    my $valid    = $valid_input;
+    $valid_input = undef;
+
+    return $valid;
 }
 
 sub errors {
@@ -195,17 +199,24 @@ Dancer2::Plugin::FormValidator - neat and easy to start form validation plugin f
 
 =head1 VERSION
 
-version 0.70
+version 0.71
 
 =head1 SYNOPSIS
 
+    ### If you need a simple and easy validation in your project,
+    ### then this module is what you need.
+
     use Dancer2::Plugin::FormValidator;
 
+    ### First create form validation profile class.
+
     package RegisterForm {
          use Moo;
          with 'Dancer2::Plugin::FormValidator::Role::Profile';
 
-         sub profile {
+        ### Here you need to declare validators.
+
+        sub profile {
             return {
                 username     => [ qw(required alpha_num_ascii length_min:4 length_max:32) ],
                 email        => [ qw(required email length_max:127) ],
@@ -213,9 +224,11 @@ version 0.70
                 password_cnf => [ qw(required same:password) ],
                 confirm      => [ qw(required accepted) ],
             };
-        };
+        }
     }
 
+    ### Now you can use it in your Dancer2 project.
+
     post '/form' => sub {
         if (validate profile => RegisterForm->new) {
             my $valid_hash_ref = validated;
@@ -227,6 +240,16 @@ version 0.70
         redirect '/form';
     };
 
+The html result could be like:
+
+=begin html
+
+<p>
+  <img alt="Screenshot register form" src="https://raw.githubusercontent.com/AlexP007/dancer2-plugin-formvalidator/645b8e8d7c91739c7618a2088841f93f47c53495/assets/screenshot_register.png" width="500px">
+</p>
+
+=end html
+
 =head1 DISCLAIMER
 
 This is alpha version, not stable.
@@ -294,6 +317,11 @@ This role requires profile method which should return a HashRef Data::FormValida
         };
     };
 
+=head3 Profile method
+
+Profile method should always return a HashRef[ArrayRef] where keys are input fields names
+and values are ArrayRef with list of validators.
+
 =head2 Application
 
 Then you need to set basic configuration:
@@ -409,7 +437,7 @@ Template app/register:
 
 =head3 validate
 
-    my $valid_hash_ref = validate(Hash $params): HashRef|undef
+    validate(Hash $params): HashRef|undef
 
 Accept params as hash:
 
@@ -423,12 +451,16 @@ Profile is required, input and lang is optional.
 
 Returns valid input HashRef if validation succeed, otherwise returns undef.
 
-    if (my $valid_hash_ref = validate 'RegisterForm') {
+    if (validate profile => RegisterForm->new) {
         # Success, data is valid.
+        my $valid_hash_ref = validated;
+
         # Do some operations...
     }
     else {
         # Error, data is invalid.
+        my $errors = errors;
+
         # Redirect or show errors...
     }
 
@@ -438,6 +470,7 @@ Returns valid input HashRef if validation succeed, otherwise returns undef.
 
 No arguments.
 Returns valid input HashRef if validate succeed.
+Undef value will be returned after first call within one validation process.
 
     my $valid_hash_ref = validated;
 
@@ -474,26 +507,50 @@ Validate that string only contain of latin alphabetic ascii symbols, underscore
 
 =head3 email
 
+Validate that field is valid email(rfc822).
+
 =head3 email_dns
 
-=head3 enum
+Validate that field is valid email(rfc822) and dns exists.
+
+=head3 enum:value1,value2
+
+Validate that field is one of listed values.
+
+    field => [ qw(enum:value1,value2) ]
 
 =head3 integer
 
+Validate that field is integer.
+
 =head3 length_max:num
 
 Validate that string length <= num.
 
+    field => [ qw(length_max:32) ]
+
 =head3 length_min:num
 
 Validate that string length >= num.
 
-=head3 max
+    field => [ qw(length_max:4) ]
 
-=head3 min
+=head3 max:num
+
+Validate that field is number <= num.
+
+    field => [ qw(max:32) ]
+
+=head3 min:num
+
+Validate that field is number >= num.
+
+    field => [ qw(min:4) ]
 
 =head3 numeric
 
+Validate that field is number.
+
 =head3 required
 
 Validate that field exists and not empty string.
@@ -515,7 +572,7 @@ Role: Dancer2::Plugin::FormValidator::Role::ProfileHasMessages.
                 name  => [qw(required)],
                 email => [qw(required email)],
             };
-        };
+        }
 
         sub messages {
             return {
@@ -532,7 +589,7 @@ Role: Dancer2::Plugin::FormValidator::Role::ProfileHasMessages.
                         en => '%s please use valid email',
                     }
                 }
-            }
+            };
         }
     }
 
@@ -624,15 +681,6 @@ L<Dancer2::Plugin::FormValidator::Extension::DBIC|https://metacpan.org/pod/Dance
 
 =over 4
 
-=item *
-Configuration details: list all fields and describe them.
-
-=item *
-Document with example and descriptions DSL's.
-
-=item *
-Document with example all validators.
-
 =item *
 Document all config field with explanation.
 
@@ -642,9 +690,6 @@ Document all Roles and HashRef structures.
 =item *
 Extensions docs.
 
-=item *
-Profile docs.
-
 =item *
 Contribution and help details.
 
