@@ -5,13 +5,15 @@ use Types::Standard qw(InstanceOf HashRef);
 use namespace::clean;
 
 has plugin => (
-    is  => 'ro',
-    isa => InstanceOf ['Dancer2::Plugin::FormValidator'],
+    is        => 'ro',
+    isa       => InstanceOf [ 'Dancer2::Plugin::FormValidator' ],
+    predicate => 1,
 );
 
 has config => (
     is  => 'ro',
     isa => HashRef,
+    predicate => 1,
 );
 
 requires 'validators';
